@@ -10,8 +10,9 @@ import multiprocessing as mp
 
 MIB_5 = 5*1024*1024
 MIN_PART_SIZE = MIB_5
-MAX_PART_SIZE = MIB_5 * 5
-MAX_PARTS = 1000000
+MID_PART_SIZE = MIB_5 * 5
+MAX_PART_SIZE = MIB_5 * 50
+MAX_PARTS = 10240
 MAX_PARALLEL = mp.cpu_count()
 MAX_RETRIES = 5
 BATCH_PRESIGNS = 200
@@ -19,6 +20,7 @@ MAX_PRESIGNS = 400
 
 CYCLE_SLEEP = 1    # progress bar refresh interval
 RETRY_SLEEP = 2    # sleep(RETRY_SLEEP * retry)
+PRESIGN_REQ_SLEEP =1
 SLOWDOWN_SLEEP = 4
 MON_TIMEOUT = 300
 WORKER_TIMEOUT = 60
